@@ -7,7 +7,7 @@ formatter = logging.Formatter("%(asctime)s [%(levelname)s] %(message)s")
 # Call getLogger with no args to set up the handler
 fixture_logger = logging.getLogger()
 fixture_logger.setLevel(logging.INFO)
-handler = logging.FileHandler(f"/logs/ra-app-oddsportal-fixtures-{date_today}.log", mode='a')
+handler = logging.FileHandler(f"/logs/ra-app-oddsportal-fixtures.log", mode='a')
 handler.setFormatter(formatter)
 fixture_logger.addHandler(handler)
 
@@ -15,6 +15,6 @@ fixture_logger.addHandler(handler)
 # Call getLogger with no args to set up the handler
 odds_logger = logging.getLogger()
 odds_logger.setLevel(logging.INFO)
-handler = logging.FileHandler(f"/logs/ra-app-oddsportal-odds-{date_today}.log", mode='a')
+handler = logging.FileHandler(f"/logs/ra-app-oddsportal-odds.log", mode='a')
 handler.setFormatter(formatter)
 odds_logger.addHandler(handler)
